@@ -98,6 +98,7 @@ extern RpcResult_t RPC_CreateTaskControl(RpcBool_t IpcFlag,RpcTaskControl_t *tsk
 		(void)RPC_MutexDestroy(&(tskCntl->mutexId));
 		return ret;
 	}
+	tskCntl->cntlSignal = RPC_FALSE;
 #else	/* USE_SEMAPHORE */
 	if((ret = RPC_SemInit(&(tskCntl->semId),IpcFlag?IPC_TACK_CNTL_SEM_SHARED:IPC_TACK_CNTL_SEM_PRIVATE,IPC_TACK_CNTL_SEM_INIT_NUM)) != RPC_SUCCESS) {
 		return ret;		
@@ -131,11 +132,14 @@ extern RpcResult_t RPC_TaskControlWait(RpcTaskControl_t *tskCntl) {
 #ifdef	USE_CANCEL_TASK
 	RPC_TaskPushCleanup(RPC_taskCntlCleanup,(void*)tskCntl);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = RPC_CondWait(&(tskCntl->condId),&(tskCntl->mutexId))) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_CondWait ret:%s",RPC_LogConvertResultCode(ret));
-		(void)RPC_MutexUnlock(&(tskCntl->mutexId));
-		return ret;			
+	while(!(tskCntl->cntlSignal)) {
+		if((ret = RPC_CondWait(&(tskCntl->condId),&(tskCntl->mutexId))) != RPC_SUCCESS) {
+			(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_CondWait ret:%s",RPC_LogConvertResultCode(ret));
+			(void)RPC_MutexUnlock(&(tskCntl->mutexId));
+			return ret;
+		}
 	}
+	tskCntl->cntlSignal = RPC_FALSE;
 #ifdef	USE_CANCEL_TASK
 	RPC_TaskPopCleanup(0);
 #endif	/* USE_CANCEL_TASK */
@@ -164,14 +168,17 @@ extern RpcResult_t RPC_TaskControlTimedWait(RpcTaskControl_t *tskCntl, struct ti
 #ifdef	USE_CANCEL_TASK
 	RPC_TaskPushCleanup(RPC_taskCntlCleanup,(void*)tskCntl);
 #endif	/* USE_CANCEL_TASK */
-	if((ret = RPC_CondWaitTimeout(&(tskCntl->condId),&(tskCntl->mutexId),specTime)) != RPC_SUCCESS) {
-		if(ret == RPC_TIMEOUT_ERROR)
-			(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_WARNING, " TIMEOUT in RPC_CondWaitTimeout ret:%s",RPC_LogConvertResultCode(ret));
-		else
-			(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_CondWaitTimeout ret:%s",RPC_LogConvertResultCode(ret));
-		(void)RPC_MutexUnlock(&(tskCntl->mutexId));
-		return ret;
+	while(!(tskCntl->cntlSignal)) {
+		if((ret = RPC_CondWaitTimeout(&(tskCntl->condId),&(tskCntl->mutexId),specTime)) != RPC_SUCCESS) {
+			if(ret == RPC_TIMEOUT_ERROR)
+				(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_WARNING, " TIMEOUT in RPC_CondWaitTimeout ret:%s",RPC_LogConvertResultCode(ret));
+			else
+				(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_CondWaitTimeout ret:%s",RPC_LogConvertResultCode(ret));
+			(void)RPC_MutexUnlock(&(tskCntl->mutexId));
+			return ret;
+		}
 	}
+	tskCntl->cntlSignal = RPC_FALSE;
 #ifdef	USE_CANCEL_TASK
 	RPC_TaskPopCleanup(0);
 #endif	/* USE_CANCEL_TASK */
@@ -201,6 +208,7 @@ extern RpcResult_t RPC_TaskControlSignal(RpcTaskControl_t *tskCntl) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_MutexLock ret:%s",RPC_LogConvertResultCode(ret));
 		return ret;
 	}
+	tskCntl->cntlSignal = RPC_TRUE;
 	if((ret = RPC_CondSignal(&(tskCntl->condId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_CondSignal ret:%s",RPC_LogConvertResultCode(ret));
 		(void)RPC_MutexUnlock(&(tskCntl->mutexId));
@@ -208,6 +216,7 @@ extern RpcResult_t RPC_TaskControlSignal(RpcTaskControl_t *tskCntl) {
 	}
 	(void)RPC_MutexUnlock(&(tskCntl->mutexId));
 #else	/* 0 */
+	tskCntl->cntlSignal = RPC_TRUE;
 	if((ret = RPC_CondSignal(&(tskCntl->condId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_CondSignal ret:%s",RPC_LogConvertResultCode(ret));
 		return ret;
@@ -225,6 +234,14 @@ extern RpcResult_t RPC_TaskControlSignal(RpcTaskControl_t *tskCntl) {
 
 extern void IPC_ResetTaskControl(RpcTaskControl_t *tskCntl) {
 #ifndef	USE_SEMAPHORE
+	{RpcResult_t ret;
+	if((ret = RPC_MutexLock(&(tskCntl->mutexId))) != RPC_SUCCESS) {
+		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_MutexLock ret:%s",RPC_LogConvertResultCode(ret));
+		return ;
+	}
+	tskCntl->cntlSignal = RPC_FALSE;
+	(void)RPC_MutexUnlock(&(tskCntl->mutexId));
+	}
 #else	/* USE_SEMAPHORE */
 	if(tskCntl == (RpcTaskControl_t*)NULL)
 		return;
@@ -442,6 +459,19 @@ extern void *RPC_SearchListEntryByString(RpcList_t *listTop,uint8_t *str,uint32_
 	return (void*)NULL;
 }
 
+#if	__WORDSIZE == 64
+extern void *RPC_SearchListEntryByDwordId(RpcList_t *listTop, uint64_t id, RPC_CompareFuncDword_t compareFunc) {
+	RpcList_t *list;
+
+	for(list = listTop;list != (RpcList_t*)NULL;list = (RpcList_t*)list->next) {
+		if(compareFunc(list,id)) {
+			return (void*)list->entry;
+		}
+	}
+	return (void*)NULL;
+}
+#endif	/* __WORDSIZE */
+
 extern uint32_t RPC_CountNumOfListEntry(RpcList_t *listTop) {
 	RpcList_t *list;uint32_t num = 0;
 
@@ -499,8 +529,10 @@ extern RpcBool_t RPC_GetRestTimeout(struct timeval *absTime,uint32_t *restTimeou
 
 	if((absTime == (struct timeval*)NULL)||(restTimeout == (uint32_t*)NULL))
 		return RPC_FALSE;
-	if(!RPC_checkTimeoutInternal(absTime,&curTime))
+	if(!RPC_checkTimeoutInternal(absTime,&curTime)) {
+		*restTimeout = 0;
 		return RPC_FALSE;
+	}
 	*restTimeout = (uint32_t)((absTime->tv_sec - curTime.tv_sec)*1000 + (absTime->tv_usec - curTime.tv_usec)/1000);
 	return RPC_TRUE;
 }
