@@ -267,7 +267,11 @@ extern IpcRendezvControl_t *IPC_GetRendezvControl(void) {
 		if(IPC_GetShmGapData(IpcShmMsgQueFd,&startAddr,&gapSize) != RPC_SUCCESS) {
 			return (IpcRendezvControl_t*)NULL;
 		}
+#if	__WORDSIZE == 64
+		rcp = (IpcRendezvControl_t*)((uint64_t)startAddr+sizeof(IpcQueControl_t));
+#else	/* __WORDSIZE */
 		rcp = (IpcRendezvControl_t*)((uint32_t)startAddr+sizeof(IpcQueControl_t));
+#endif	/* __WORDSIZE */
 		return rcp;
 	}
 }
