@@ -286,9 +286,15 @@ extern RpcResult_t IPC_InitShmGapArea(int fd, uint32_t gapSize) {
 	}
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"    Addr:0x%x;",addr);	
 	ap = (IpcShmManageArea_t*)addr;
+#if	__WORDSIZE == 64
+	mp = (void*)((uint64_t)addr + IPC_ALIGNMENT(gapSize) + sizeof(IpcShmManageArea_t));
+	ap->startOfIpcAreaManageInfo = (void*)mp;
+	ap->startOfGap = (void*)((uint64_t)addr + sizeof(IpcShmManageArea_t));
+#else	/* __WORDSIZE */
 	mp = (void*)((uint32_t)addr + IPC_ALIGNMENT(gapSize) + sizeof(IpcShmManageArea_t));
 	ap->startOfIpcAreaManageInfo = (void*)mp;
 	ap->startOfGap = (void*)((uint32_t)addr + sizeof(IpcShmManageArea_t));
+#endif	/* __WORDSIZE */
 	ap->gapSize = gapSize;
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"END IPC_InitShmGapArea PID:0x%x; ap:0x%x; offsetIpcAreaManageInfo:0x%x; offsetGap:0x%x; gapSize:0x%x;",
 //		RPC_GetPid(),ap, ap->offsetOfIpcAreaManageInfo, ap->offsetOfGap, ap->gapSize);
@@ -374,31 +380,54 @@ extern RpcResult_t IPC_InitShmAllocArea(int fd, uint32_t memSize, uint32_t numOf
 		goto fatalError;
 	}
 */
+#if	__WORDSIZE == 64
+	areaInfo = manageInfo->areaInfo = (IpcAreaInfo_t*)((uint64_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+	topAddr = (void*)((uint64_t)areaInfo + sizeof(IpcAreaInfo_t)*numOfDev);
+#else	/* __WORDSIZE */
 	areaInfo = manageInfo->areaInfo = (IpcAreaInfo_t*)((uint32_t)manageInfo + sizeof(IpcAreaManageInfo_t));
 	topAddr = (void*)((uint32_t)areaInfo + sizeof(IpcAreaInfo_t)*numOfDev);
+#endif	/* __WORDSIZE */
 	blockSize = memSize/(1<<(numOfDev-1));
 	bSize = minSize;
 	blockNum = blockSize / bSize;
 	for(i = 0;i < (numOfDev-1);i++) {
 		areaInfo->info.fixedAreaInfo.topAddr = topAddr;
+#if	__WORDSIZE == 64
+		areaInfo->info.fixedAreaInfo.tailAddr = (void*)((uint64_t)topAddr + blockSize - 1);
+#else	/* __WORDSIZE */
 		areaInfo->info.fixedAreaInfo.tailAddr = (void*)((uint32_t)topAddr + blockSize - 1);
+#endif	/* __WORDSIZE */
 		areaInfo->info.fixedAreaInfo.numOfBlocks = blockNum;
 		areaInfo->info.fixedAreaInfo.sizeOfBlock = bSize;
 		areaInfo->info.fixedAreaInfo.freeListTop = topAddr;
 		*((uint32_t*)topAddr) = blockNum;
+#if	__WORDSIZE == 64
+		*((uint32_t*)((int64_t)topAddr + sizeof(uint32_t))) = 0;
+		areaInfo++;
+		topAddr = (void*)((uint64_t)topAddr + blockSize);
+#else	/* __WORDSIZE */
 		*((uint32_t*)((int32_t)topAddr + sizeof(uint32_t))) = 0;
 		areaInfo++;
 		topAddr = (void*)((uint32_t)topAddr + blockSize);
+#endif	/* __WORDSIZE */
 		blockSize = memSize/(1<<(numOfDev-1-i));
 		bSize = bSize * rateOfMagnify;
 		blockNum = blockSize/bSize;
 	}
 	areaInfo->info.freeAreaInfo.topAddr = topAddr;
+#if	__WORDSIZE == 64
+	areaInfo->info.freeAreaInfo.tailAddr = (void*)((uint64_t)topAddr + blockSize - 1);
+#else	/* __WORDSIZE */
 	areaInfo->info.freeAreaInfo.tailAddr = (void*)((uint32_t)topAddr + blockSize - 1);
+#endif	/* __WORDSIZe */
 	areaInfo->info.freeAreaInfo.freeListTop = topAddr;
 	areaInfo->info.freeAreaInfo.usedListTop = (void*)NULL;
 	*((uint32_t*)(topAddr)) = blockSize;
+#if	__WORDSIZE == 64
+	*((uint32_t*)((int64_t)topAddr + sizeof(uint32_t))) = 0;
+#else	/* __WORDSIZE */
 	*((uint32_t*)((int32_t)topAddr + sizeof(uint32_t))) = 0;
+#endif	/* __WORDSIZE */
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"END IPC_InitShmAllocArea PID:0x%x; START-ADDR:0x%x;", 
 //		RPC_GetPid(), addr);
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"   AREA-INFO:0x%x; TopAddr:0x%x; TailAddr:0x%x; FreeListTop:0x%x; UsedListTop:0x%x;", 
@@ -434,7 +463,11 @@ extern void *IPC_AllocShmMem(int fd, uint32_t size) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_FATAL,"MUTEX ERROR");
 		return (void*)NULL;
 	}
+#if	__WORDSIZE == 64
+	areaInfo = (IpcAreaInfo_t*)((uint64_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#else	/* __WORDSIZE */
 	areaInfo = (IpcAreaInfo_t*)((uint32_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#endif	/* __WORDSIZE */
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"   BEFORE AREA-INFO AreaInfo:0x%x; TopAddr:0x%x; TailAddr:0x%x; freeInfo:0x%x; usedInfo:0x%x;",
 //		areaInfo, areaInfo->info.freeAreaInfo.topAddr, areaInfo->info.freeAreaInfo.tailAddr, 
 //		areaInfo->info.freeAreaInfo.freeListTop, areaInfo->info.freeAreaInfo.usedListTop);
@@ -448,8 +481,13 @@ extern void *IPC_AllocShmMem(int fd, uint32_t size) {
 				areaInfo->info.fixedAreaInfo.freeListTop = fixedInfo->nextFreeArea;
 			}
 			else {
+#if	__WORDSIZE == 64
+				areaInfo->info.fixedAreaInfo.freeListTop = (void*)((uint64_t)areaInfo->info.fixedAreaInfo.freeListTop+
+						areaInfo->info.fixedAreaInfo.sizeOfBlock);
+#else	/* __WORDSIZE */
 				areaInfo->info.fixedAreaInfo.freeListTop = (void*)((uint32_t)areaInfo->info.fixedAreaInfo.freeListTop+
 						areaInfo->info.fixedAreaInfo.sizeOfBlock);
+#endif	/* __WORDSIZE */
 				((IpcFixedAreaFreeInfo_t*)areaInfo->info.fixedAreaInfo.freeListTop)->numOfBlocks = fixedInfo->numOfBlocks;
 				((IpcFixedAreaFreeInfo_t*)areaInfo->info.fixedAreaInfo.freeListTop)->nextFreeArea = fixedInfo->nextFreeArea;
 			}
@@ -480,7 +518,11 @@ extern void *IPC_AllocShmMem(int fd, uint32_t size) {
 			}
 			else {
 				size = IPC_ALIGNMENT(size);
+#if	__WORDSIZE == 64
+				newFreeInfo = (IpcFreeAreaFreeInfo_t*)((uint64_t)freeInfo+size+sizeof(IpcFreeAreaFreeInfo_t));
+#else	/* __WORDSIZE */
 				newFreeInfo = (IpcFreeAreaFreeInfo_t*)((uint32_t)freeInfo+size+sizeof(IpcFreeAreaFreeInfo_t));
+#endif	/* __WORDSIZE */
 				newFreeInfo->size = freeInfo->size - (size+sizeof(IpcFreeAreaFreeInfo_t));
 				newFreeInfo->nextBlock = freeInfo->nextBlock;
 				if(preFreeInfo == (IpcFreeAreaFreeInfo_t*)NULL) {
@@ -504,7 +546,11 @@ extern void *IPC_AllocShmMem(int fd, uint32_t size) {
 			}
 			newUsedInfo->nextBlock = (void*)usedInfo;
 			newUsedInfo->size = size;
+#if	__WORDSIZE == 64
+			retAddr = (void*)((uint64_t)newUsedInfo+sizeof(IpcFreeAreaUsedInfo_t));
+#else	/* __WORSIZE */
 			retAddr = (void*)((uint32_t)newUsedInfo+sizeof(IpcFreeAreaUsedInfo_t));
+#endif	/* __WORDSIZE */
 //			(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"   END AREA-INFO AreaInfo:0x%x; TopAddr:0x%x; TailAddr:0x%x; freeInfo:0x%x; usedInfo:0x%x;",
 //				areaInfo, areaInfo->info.freeAreaInfo.topAddr, areaInfo->info.freeAreaInfo.tailAddr, 
 //				areaInfo->info.freeAreaInfo.freeListTop, areaInfo->info.freeAreaInfo.usedListTop);
@@ -541,7 +587,11 @@ extern void IPC_FreeShmMem(int fd, void *addr) {
 	if(RPC_MutexLock(&(manageInfo->mutexId)) != RPC_SUCCESS) {
 		return;
 	}
+#if	__WORDSIZE == 64
+	areaInfo = (IpcAreaInfo_t*)((uint64_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#else	/* __WORDSIZE */
 	areaInfo = (IpcAreaInfo_t*)((uint32_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#endif	/* __WORDSIZE */
 	for(i = 0;i < (manageInfo->numOfDev-1);i++) {
 		if((addr >= areaInfo->info.fixedAreaInfo.topAddr)&&(addr < areaInfo->info.fixedAreaInfo.tailAddr)) {
 			preFixedInfo = (IpcFixedAreaFreeInfo_t*)NULL;
@@ -552,21 +602,37 @@ extern void IPC_FreeShmMem(int fd, void *addr) {
 					((IpcFixedAreaFreeInfo_t*)addr)->numOfBlocks = 1;
 					if(preFixedInfo == (IpcFixedAreaFreeInfo_t*)NULL) {
 						areaInfo->info.fixedAreaInfo.freeListTop = (void*)addr;
+#if	__WORDSIZE == 64
+						if(((uint64_t)addr+areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint64_t)fixedInfo) {
+#else	/* __WORDSIZE */
 						if(((uint32_t)addr+areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint32_t)fixedInfo) {
+#endif	/* __WORDSIZE */
 							((IpcFixedAreaFreeInfo_t*)addr)->numOfBlocks = fixedInfo->numOfBlocks+1;
 							((IpcFixedAreaFreeInfo_t*)addr)->nextFreeArea = fixedInfo->nextFreeArea;
 						}
 					}
+#if	__WORDSIZE == 64
+					else if((uint64_t)preFixedInfo+(preFixedInfo->numOfBlocks * areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint64_t)addr) {
+#else	/* __WORDSIZE */
 					else if((uint32_t)preFixedInfo+(preFixedInfo->numOfBlocks * areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint32_t)addr) {
+#endif	/* __WORDSIZE */
 						(preFixedInfo->numOfBlocks)++;
+#if	__WORDSIZE == 64
+						if(((uint64_t)addr+areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint64_t)fixedInfo) {
+#else	/* __WORDSIZE */
 						if(((uint32_t)addr+areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint32_t)fixedInfo) {
+#endif	/* __WORDSIZE */
 							preFixedInfo->numOfBlocks += fixedInfo->numOfBlocks;
 							preFixedInfo->nextFreeArea = fixedInfo->nextFreeArea;
 						}
 					}
 					else {
 						preFixedInfo->nextFreeArea = (void*)addr;
+#if	__WORDSIZE == 64
+						if(((uint64_t)addr+areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint64_t)fixedInfo) {
+#else	/* __WORDSIZE */
 						if(((uint32_t)addr+areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint32_t)fixedInfo) {
+#endif	/* __WORDSIZE */
 							((IpcFixedAreaFreeInfo_t*)addr)->numOfBlocks = fixedInfo->numOfBlocks+1;
 							((IpcFixedAreaFreeInfo_t*)addr)->nextFreeArea = fixedInfo->nextFreeArea;
 						}
@@ -582,7 +648,11 @@ extern void IPC_FreeShmMem(int fd, void *addr) {
 			if(preFixedInfo == (IpcFixedAreaFreeInfo_t*)NULL) {
 				areaInfo->info.fixedAreaInfo.freeListTop = (void*)addr;
 			}
+#if	__WORDSIZE == 64
+			else if((uint64_t)preFixedInfo+(preFixedInfo->numOfBlocks * areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint64_t)addr) {
+#else	/* __WORDSIZE */
 			else if((uint32_t)preFixedInfo+(preFixedInfo->numOfBlocks * areaInfo->info.fixedAreaInfo.sizeOfBlock) == (uint32_t)addr) {
+#endif	/* __WORDSIZE */
 				(preFixedInfo->numOfBlocks)++;
 			}
 			else {
@@ -594,12 +664,20 @@ extern void IPC_FreeShmMem(int fd, void *addr) {
 		areaInfo++;
 	}
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"NOW SEARCH FREE AREA:0x%x;",addr);
+#if	__WORDSIZE == 64
+	addr = (void*)((uint64_t)addr-sizeof(IpcFreeAreaUsedInfo_t));
+#else	/* __WORDSIZE */
 	addr = (void*)((uint32_t)addr-sizeof(IpcFreeAreaUsedInfo_t));
+#endif	/* __WORDSIZE */
 	if((addr >= areaInfo->info.freeAreaInfo.topAddr)&&(addr < areaInfo->info.freeAreaInfo.tailAddr)) {
 		usedInfo = (IpcFreeAreaUsedInfo_t*)areaInfo->info.freeAreaInfo.usedListTop;
 		preUsedInfo = (IpcFreeAreaUsedInfo_t*)NULL;
 		while(usedInfo != (IpcFreeAreaUsedInfo_t*)NULL) {
+#if	__WORDSIZE == 64
+			if(((uint64_t)usedInfo+sizeof(IpcFreeAreaUsedInfo_t)) >= (uint64_t)addr) {
+#else	/* __WORDSIZE */
 			if(((uint32_t)usedInfo+sizeof(IpcFreeAreaUsedInfo_t)) >= (uint32_t)addr) {
+#endif	/* __WORDSIZE */
 //				(void)RPC_LogPrint(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"FIND AREA:0x%x; PRE:0x%x; SIZE:%d; AREA:0x%x; SIZE:%d; NEXT:0x%x;",addr,preUsedInfo,(preUsedInfo!=NULL)?(preUsedInfo->size):0,usedInfo,usedInfo->size,usedInfo->nextBlock);
 				if(preUsedInfo == (IpcFreeAreaUsedInfo_t*)NULL) {
 					areaInfo->info.freeAreaInfo.usedListTop = usedInfo->nextBlock;
@@ -610,7 +688,11 @@ extern void IPC_FreeShmMem(int fd, void *addr) {
 				freeInfo = (IpcFreeAreaFreeInfo_t*)areaInfo->info.freeAreaInfo.freeListTop;
 				preFreeInfo = (IpcFreeAreaFreeInfo_t*)NULL;
 				while(freeInfo != (IpcFreeAreaFreeInfo_t*)NULL) {
+#if	__WORDSIZE == 64
+					if((uint64_t)usedInfo <= (uint64_t)freeInfo) {
+#else	/* __WORDSIZE */
 					if((uint32_t)usedInfo <= (uint32_t)freeInfo) {
+#endif	/* __WORDSIZE */
 						usedInfo->nextBlock = (void*)freeInfo;
 						if(preFreeInfo == (IpcFreeAreaFreeInfo_t*)NULL) {
 							areaInfo->info.freeAreaInfo.freeListTop = (void*)usedInfo;
@@ -618,12 +700,21 @@ extern void IPC_FreeShmMem(int fd, void *addr) {
 						else {
 							preFreeInfo->nextBlock = (void*)(usedInfo);
 						}
+#if	__WORDSIZE == 64
+						if(((uint64_t)usedInfo+usedInfo->size+sizeof(IpcFreeAreaFreeInfo_t)) == (uint64_t)freeInfo) {
+#else	/* __WORDSIZE */
 						if(((uint32_t)usedInfo+usedInfo->size+sizeof(IpcFreeAreaFreeInfo_t)) == (uint32_t)freeInfo) {
+#endif	/* __WORDSIZE */
 							usedInfo->nextBlock = freeInfo->nextBlock;
 							usedInfo->size += (freeInfo->size+sizeof(IpcFreeAreaFreeInfo_t));
 						}
+#if	__WORDSIZE == 64
+						if(((preFreeInfo != (IpcFreeAreaFreeInfo_t*)NULL)&&
+								((uint64_t)preFreeInfo+preFreeInfo->size+sizeof(IpcFreeAreaFreeInfo_t)) == (uint64_t)usedInfo)) {
+#else	/* __WORDSIZE */
 						if(((preFreeInfo != (IpcFreeAreaFreeInfo_t*)NULL)&&
 								((uint32_t)preFreeInfo+preFreeInfo->size+sizeof(IpcFreeAreaFreeInfo_t)) == (uint32_t)usedInfo)) {
+#endif	/* __WORDSIZE */
 							preFreeInfo->nextBlock = usedInfo->nextBlock;
 							preFreeInfo->size += (usedInfo->size+sizeof(IpcFreeAreaFreeInfo_t));
 						}
@@ -638,7 +729,11 @@ extern void IPC_FreeShmMem(int fd, void *addr) {
 				if(preFreeInfo == (IpcFreeAreaFreeInfo_t*)NULL) {
 					areaInfo->info.freeAreaInfo.freeListTop = (void*)usedInfo;
 				}
+#if	__WORDSIZE == 64
+				else if(((uint64_t)preFreeInfo+preFreeInfo->size+sizeof(IpcFreeAreaFreeInfo_t)) == (uint64_t)(usedInfo)) {
+#else	/* __WORDSIZE */
 				else if(((uint32_t)preFreeInfo+preFreeInfo->size+sizeof(IpcFreeAreaFreeInfo_t)) == (uint32_t)(usedInfo)) {
+#endif	/* __WORDSIZE */
 					preFreeInfo->size += (usedInfo->size+sizeof(IpcFreeAreaFreeInfo_t));
 				}
 				else {
@@ -674,7 +769,11 @@ extern uint32_t IPC_AllocatedSizeShmMem(int fd, void *addr) {
 	if(RPC_MutexLock(&(manageInfo->mutexId)) != RPC_SUCCESS) {
 		return 0;
 	}
+#if	__WORDSIZE == 64
+	areaInfo = (IpcAreaInfo_t*)((uint64_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#else	/* __WORDSIZE */
 	areaInfo = (IpcAreaInfo_t*)((uint32_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#endif	/* __WORDSIZE */
 	for(i = 0;i < (manageInfo->numOfDev-1);i++) {
 		if((addr >= areaInfo->info.fixedAreaInfo.topAddr)&&(addr < areaInfo->info.fixedAreaInfo.tailAddr)) {
 			fixedInfo = (IpcFixedAreaFreeInfo_t*)areaInfo->info.fixedAreaInfo.freeListTop;
@@ -694,7 +793,11 @@ extern uint32_t IPC_AllocatedSizeShmMem(int fd, void *addr) {
 	if((addr >= areaInfo->info.freeAreaInfo.topAddr)&&(addr < areaInfo->info.freeAreaInfo.tailAddr)) {
 		usedInfo = (IpcFreeAreaUsedInfo_t*)areaInfo->info.freeAreaInfo.usedListTop;
 		while(usedInfo != (IpcFreeAreaUsedInfo_t*)NULL) {
+#if	__WORDSIZE == 64
+			if(((uint64_t)usedInfo+sizeof(IpcFreeAreaUsedInfo_t)) >= (uint64_t)addr) {
+#else	/* __WORDSIZE */
 			if(((uint32_t)usedInfo+sizeof(IpcFreeAreaUsedInfo_t)) >= (uint32_t)addr) {
+#endif	/* __WORDSIZE */
 				size = usedInfo->size;
 				(void)RPC_MutexUnlock(&(manageInfo->mutexId));
 				return size;
@@ -770,7 +873,11 @@ static void IPC_printFixedAreaList(int fd) {
 	}
 	(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"---- FixedFreeList manageInfo:0x%x; areaInfo:0x%x; areaSize:%d; numOfDev:%d; rateOfMagnify:%d; sizeOfMinDev:0x%x; ----\n",
 			manageInfo,manageInfo->areaInfo,manageInfo->areaSize,manageInfo->numOfDev,manageInfo->rateOfMagnify,manageInfo->sizeOfMinDev);
+#if	__WORDSIZE == 64
+	areaInfo = (IpcAreaInfo_t*)((uint64_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#else	/* __WORDSIZE */
 	areaInfo = (IpcAreaInfo_t*)((uint32_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#endif	/* __WORDSIZE */
 	for(i = 0;i < (manageInfo->numOfDev-1);i++) {
 		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"  -- areaInfo:0x%x; numOfBlocks:%d; sizeOfBlock:%d; topAddr:0x%x; tailAddr:0x%x; freeListTop:0x%x; --\n",
 				areaInfo,areaInfo->info.fixedAreaInfo.numOfBlocks,areaInfo->info.fixedAreaInfo.sizeOfBlock,areaInfo->info.fixedAreaInfo.topAddr,
@@ -803,7 +910,11 @@ static void IPC_printFreeAreaList(int fd) {
 	}
 //	(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM,RPC_LOG_LEVEL_DEBUG1,"---- FixedFreeList manageInfo:0x%x; areaInfo:0x%x; areaSize:%d; numOfDev:%d; rateOfMagnify:%d; sizeOfMinDev:0x%x; ----\n",
 //			manageInfo,(uint32_t)manageInfo + sizeof(IpcAreaManageInfo_t),manageInfo->areaSize,manageInfo->numOfDev,manageInfo->rateOfMagnify,manageInfo->sizeOfMinDev);
+#if	__WORDSIZE == 64
+	areaInfo = (IpcAreaInfo_t*)((uint64_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#else	/* __WORDSIZE */
 	areaInfo = (IpcAreaInfo_t*)((uint32_t)manageInfo + sizeof(IpcAreaManageInfo_t));
+#endif	/* __WORDSIZE */
 	for(i = 0;i < (manageInfo->numOfDev-1);i++) {
 		areaInfo++;
 	}
