@@ -55,7 +55,7 @@ typedef struct {
 
 typedef struct {
 	uint32_t processId;
-	uint32_t taskId;
+	RpcTaskID_t taskId;
 	uint32_t queId;
 //	IpcProcessType_t processType;
 } IpcSkeltonDBEntry_t;
@@ -316,11 +316,11 @@ extern RpcResult_t IPC_DeleteFuncDBEntry(uint32_t funcId) {
 	return RPC_SUCCESS;
 }
 
-//extern RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,uint32_t taskId, uint32_t queId,IpcProcessType_t processType) {
-extern RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,uint32_t taskId, uint32_t queId) {
+//extern RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,RpcTaskID_t taskId, uint32_t queId,IpcProcessType_t processType) {
+extern RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,RpcTaskID_t taskId, uint32_t queId) {
 	IpcSkeltonDBEntry_t *entry;RpcResult_t ret;
 
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB, RPC_LOG_LEVEL_DEBUG1, "IN IPC_RegisterSkeltonDBEntry processId:0x%x; taskId:0x%x; queId:0x%x; ipcDBMange:0x%x;",
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB, RPC_LOG_LEVEL_DEBUG1, "IN IPC_RegisterSkeltonDBEntry processId:0x%x; taskId:0x%Lx; queId:0x%x; ipcDBMange:0x%x;",
 //		processId, taskId, queId,IpcDBManage);
 	if((IpcDatabaseSharedMemId == -1)||(IpcDBManage == (IpcDBManage_t*)NULL)) {
 		return RPC_NOT_READY;
@@ -349,7 +349,7 @@ extern RpcResult_t IPC_RegisterSkeltonDBEntry(uint32_t processId,uint32_t taskId
 	return RPC_SUCCESS;
 }
 
-extern RpcResult_t IPC_SearchSkeltonDB(uint32_t processId, uint32_t *taskId,uint32_t *queId) {
+extern RpcResult_t IPC_SearchSkeltonDB(uint32_t processId, RpcTaskID_t *taskId,uint32_t *queId) {
 	IpcSkeltonDBEntry_t *entry;RpcResult_t ret;
 
 	if((IpcDatabaseSharedMemId == -1)||(IpcDBManage == (IpcDBManage_t*)NULL)) {
@@ -847,26 +847,51 @@ static void IPC_dumpDB(void) {
 		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"DBMANGE:NULL\n");
 		return;
 	}
+#if	__WORDSIZE == 64
+	(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"--- DBManage:0x%Lx; funcDB:0x%Lx; skeltonDB:0x%Lx; hashRandTable:0x%Lx; funcDBHashTable:0x:%Lx;---\n",
+			(uint64_t)IpcDBManage,(uint64_t)IpcDBManage->funcDB,(uint64_t)IpcDBManage->skeltonDB,(uint64_t)IpcDBManage->hashRandTable,(uint64_t)IpcDBManage->funcDBHashTable);
+#else	/* __WORDSIZE */
 	(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"--- DBManage:0x%x; funcDB:0x%x; skeltonDB:0x%x; hashRandTable:0x%x; funcDBHashTable:0x:%x;---\n",
 			(uint32_t)IpcDBManage,(uint32_t)IpcDBManage->funcDB,(uint32_t)IpcDBManage->skeltonDB,(uint32_t)IpcDBManage->hashRandTable,(uint32_t)IpcDBManage->funcDBHashTable);
+#endif	/* __WORDSIZE */
 	(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"  -- FUNC DB --\n");
 	for(funcList = IpcDBManage->funcDB;funcList != NULL;funcList = (RpcList_t*)funcList->next) {
+#if	__WORDSIZE == 64
+		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"   funcId:%d; processId:%d; skelton:0x%Lx; cancel:0x%Lx; ",
+				((IpcFuncDBEntry_t*)funcList->entry)->funcId,((IpcFuncDBEntry_t*)funcList->entry)->processId,(uint64_t)((IpcFuncDBEntry_t*)funcList->entry)->skeltonFunc,(uint64_t)((IpcFuncDBEntry_t*)funcList->entry)->cancelFunc);
+		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"  NEXT:0x%Lx;\n",(uint64_t)funcList->next);
+#else	/* __WORDSIZE */
 		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"   funcId:%d; processId:%d; skelton:0x%x; cancel:0x%x; ",
 				((IpcFuncDBEntry_t*)funcList->entry)->funcId,((IpcFuncDBEntry_t*)funcList->entry)->processId,(uint32_t)((IpcFuncDBEntry_t*)funcList->entry)->skeltonFunc,(uint32_t)((IpcFuncDBEntry_t*)funcList->entry)->cancelFunc);
 		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"  NEXT:0x%x;\n",(uint32_t)funcList->next);
+#endif	/* __WORDSIZE */
 	}
 	(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"  -- SKELTON DB --\n");
 	for(skeltonList = IpcDBManage->skeltonDB;skeltonList != NULL;skeltonList = (RpcList_t*)skeltonList->next) {
+#if	__WORDSIZE == 64
+		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"   processId:%d; taskId:%Ld; queId:%d; ",
+				((IpcSkeltonDBEntry_t*)skeltonList->entry)->processId,((IpcSkeltonDBEntry_t*)skeltonList->entry)->taskId,((IpcSkeltonDBEntry_t*)skeltonList->entry)->queId);
+		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"  NEXT:0x%Lx;\n",(uint64_t)skeltonList->next);
+#else	/* __WORDSIZE */
 		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"   processId:%d; taskId:%d; queId:%d; ",
 				((IpcSkeltonDBEntry_t*)skeltonList->entry)->processId,((IpcSkeltonDBEntry_t*)skeltonList->entry)->taskId,((IpcSkeltonDBEntry_t*)skeltonList->entry)->queId);
 		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"  NEXT:0x%x;\n",(uint32_t)skeltonList->next);
+#endif	/* __WORDSIZE */
 	}
 #ifdef	USE_MULTICAST_RPC
 	(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"  -- MULTICAST FUNC DB --\n");
 	if(IpcDBManage->mltcstFuncDB != NULL) {
+#if	__WORDSIZE == 64
+		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"   MutexID:0x%Lx; MutexAttr:0x%Lx FuncListTop:0x%Lx;\n",(uint64_t)(&(IpcDBManage->mltcstFuncDB->mltcstMutexId)),(uint64_t)(&(IpcDBManage->mltcstFuncDB->mltcstMutexAttr)),(uint64_t)(IpcDBManage->mltcstFuncDB->mltcstFuncListTop));
+#else	/* __WORDSIZE */
 		(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"   MutexID:0x%x; MutexAttr:0x%x FuncListTop:0x%x;\n",(uint32_t)(&(IpcDBManage->mltcstFuncDB->mltcstMutexId)),(uint32_t)(&(IpcDBManage->mltcstFuncDB->mltcstMutexAttr)),(uint32_t)(IpcDBManage->mltcstFuncDB->mltcstFuncListTop));
+#endif	/* __WORDSIZE */
 		for(mDBList = IpcDBManage->mltcstFuncDB->mltcstFuncListTop;mDBList != NULL;mDBList = (RpcList_t*)mDBList->next) {
+#if	__WORDSIZE == 64
+			(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"     mtlcstFuncId:0x%x; regProcessId:0x%x; FuncEntryTop:0x%Lx;\n",((IpcMltcstFuncList_t*)mDBList->entry)->mltcstFuncId, ((IpcMltcstFuncList_t*)mDBList->entry)->regProcessId, (uint64_t)(((IpcMltcstFuncList_t*)mDBList->entry)->mltcstFuncEntryTop));
+#else	/* __WORDSIZE */
 			(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"     mtlcstFuncId:0x%x; regProcessId:0x%x; FuncEntryTop:0x%x;\n",((IpcMltcstFuncList_t*)mDBList->entry)->mltcstFuncId, ((IpcMltcstFuncList_t*)mDBList->entry)->regProcessId, (uint32_t)(((IpcMltcstFuncList_t*)mDBList->entry)->mltcstFuncEntryTop));
+#endif	/* __WORDSIZE */
 			(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"        --- MULTICAST FUNC LIST ---\n");
 			for(funcList = ((IpcMltcstFuncList_t*)mDBList->entry)->mltcstFuncEntryTop;funcList != NULL; funcList = funcList->next) {
 				(void)RPC_LogPrintNomark(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_DEBUG1,"          processId:0x%x; funcId:0x%x;\n",((IpcMltcstFuncEntry_t*)funcList->entry)->processId,((IpcMltcstFuncEntry_t*)funcList->entry)->funcId);
@@ -906,7 +931,8 @@ RpcResult_t DBTest(void);
 RpcResult_t DBTest(void) {
 	RpcResult_t ret;int i,j;int dice;
 	IpcSkeltonDBEntry_t skelDB[20];
-	IpcFuncDBEntry_t funcDB[20];uint32_t processId,taskId,queId;//void *func,*cancelFunc;
+	IpcFuncDBEntry_t funcDB[20];uint32_t processId,queId;//void *func,*cancelFunc;
+	RpcTaskID_t taskId;
 	int32_t (*func)(uint32_t processId, uint32_t seqNum, void *inData ,uint32_t inSize, void **outData, int32_t *outSize, uint32_t timeOut);
 	int32_t (*cancelFunc)(uint32_t processId, uint32_t seqNum);
 //	uint16_t accessProcessType;uint16_t accessDeviceType;
@@ -992,7 +1018,7 @@ RpcResult_t DBTest(void) {
 	}
 	for(i = 0;i < 20;i++) {
 		skelDB[i].processId = i+1;
-		skelDB[i].taskId = i+1;
+		skelDB[i].taskId = (RpcTaskID_t)(i+1);
 		skelDB[i].queId = i+1;
 //		skelDB[i].processType = PROCESS_TYPE_TEST;
 	}
@@ -1080,7 +1106,11 @@ RpcResult_t DBTest(void) {
 		(void)IPC_DestroySharedMem();
 		return ret;								
 	}
+#if	__WORDSIZE ==64
+	fprintf(stdout,"== SEARCH OK funcId:2; func:0x%Lx; cancelFunc:0x%Lx;\n",(uint64_t)func,(uint64_t)cancelFunc);
+#else	/* __WORDSIZE */
 	fprintf(stdout,"== SEARCH OK funcId:2; func:0x%x; cancelFunc:0x%x;\n",(uint32_t)func,(uint32_t)cancelFunc);
+#endif	/* __WORDSIZE */
 //	if((ret = IPC_SearchFunctionFromFuncDB(11,&func,&cancelFunc,&accessProcessType,&accessDeviceType)) != RPC_SUCCESS) {
 	if((ret = IPC_SearchFunctionFromFuncDB(11,&func,&cancelFunc)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_SearchFunctionFromFuncDB ret:%s;",RPC_LogConvertResultCode(ret));
@@ -1088,7 +1118,11 @@ RpcResult_t DBTest(void) {
 		(void)IPC_DestroySharedMem();
 		return ret;								
 	}
+#if	__WORDSIZE == 64
+	fprintf(stdout,"== SEARCH OK funcId:11; func:0x%Lx; cancelFunc:0x%Lx;\n",(uint64_t)func,(uint64_t)cancelFunc);
+#else	/* __WORDSIZE */
 	fprintf(stdout,"== SEARCH OK funcId:11; func:0x%x; cancelFunc:0x%x;\n",(uint32_t)func,(uint32_t)cancelFunc);
+#endif	/* __WORDSIZE */
 //	if((ret = IPC_SearchFunctionFromFuncDB(19,&func,&cancelFunc,&accessProcessType,&accessDeviceType)) != RPC_SUCCESS) {
 	if((ret = IPC_SearchFunctionFromFuncDB(19,&func,&cancelFunc)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_SearchFunctionFromFuncDB ret:%s;",RPC_LogConvertResultCode(ret));
@@ -1096,7 +1130,11 @@ RpcResult_t DBTest(void) {
 		(void)IPC_DestroySharedMem();
 		return ret;								
 	}
+#if	__WORDSIZE == 64
+	fprintf(stdout,"== SEARCH OK funcId:19; func:0x%Lx; cancelFunc:0x%Lx;\n",(uint64_t)func,(uint64_t)cancelFunc);
+#else	/* __WORDSIZE */
 	fprintf(stdout,"== SEARCH OK funcId:19; func:0x%x; cancelFunc:0x%x;\n",(uint32_t)func,(uint32_t)cancelFunc);
+#endif	/* __WORDSIZE */
 //	if((ret = IPC_SearchFunctionFromFuncDB(10,&func,&cancelFunc,&accessProcessType,&accessDeviceType)) == RPC_SUCCESS) {
 	if((ret = IPC_SearchFunctionFromFuncDB(10,&func,&cancelFunc)) == RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_SearchFunctionFromFuncDB ret:%s;",RPC_LogConvertResultCode(ret));
@@ -1111,21 +1149,21 @@ RpcResult_t DBTest(void) {
 		(void)IPC_DestroySharedMem();
 		return ret;								
 	}
-	fprintf(stdout,"== SEARCH OK processId:2; taskId:%d; queId:%d;\n",taskId,queId);
+	fprintf(stdout,"== SEARCH OK processId:2; taskId:%Ld; queId:%d;\n",taskId,queId);
 	if((ret = IPC_SearchSkeltonDB(11, &taskId,&queId)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_SearchSkeltonDB ret:%s;",RPC_LogConvertResultCode(ret));
 		(void)IPC_DettachSharedMem();
 		(void)IPC_DestroySharedMem();
 		return ret;								
 	}
-	fprintf(stdout,"== SEARCH OK processId:19; taskId:%d; queId:%d;\n",taskId,queId);
+	fprintf(stdout,"== SEARCH OK processId:19; taskId:%Ld; queId:%d;\n",taskId,queId);
 	if((ret = IPC_SearchSkeltonDB(11, &taskId,&queId)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_SearchSkeltonDB ret:%s;",RPC_LogConvertResultCode(ret));
 		(void)IPC_DettachSharedMem();
 		(void)IPC_DestroySharedMem();
 		return ret;								
 	}
-	fprintf(stdout,"== SEARCH OK processId:19; taskId:%d; queId:%d;\n",taskId,queId);
+	fprintf(stdout,"== SEARCH OK processId:19; taskId:%Ld; queId:%d;\n",taskId,queId);
 	if((ret = IPC_SearchSkeltonDB(10, &taskId,&queId)) == RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SHM_DB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_SearchSkeltonDB ret:%s;",RPC_LogConvertResultCode(ret));
 		(void)IPC_DettachSharedMem();
