@@ -72,19 +72,27 @@ typedef struct {
 
 static IpcSkeltonResourceDBManage_t IpcSkeltonRcsDBManage;
 static uint32_t IpcSkeltonManagerQueId = 0xFFFFFFFF;
-static RpcTaskID_t IpcSkeltonManagerTaksId = (RpcTaskID_t)0xFFFFFFFF;
+#if	__WORDSIZE == 64
+static RpcTaskID_t IpcSkeltonManagerTaskId = (RpcTaskID_t)0xFFFFFFFFFFFFFFFF;
+#else	/* __WORDSIZE */
+static RpcTaskID_t IpcSkeltonManagerTaskId = (RpcTaskID_t)0xFFFFFFFF;
+#endif	/* __WORDSIZE */
 static RpcTaskAttribute_t IpcSkeltonManagerTaskAttr;
 
 static void *IPC_skeltonManagerMain(void *arg1);
 static void *IPC_skeltonTaskMain(void *arg1);
 
 static RpcResult_t IPC_initSkeltonResourceDB(void);
-static RpcResult_t IPC_allocTaskFromSkeltonResourceDB(uint32_t *taskId,uint32_t *queId);
-static RpcResult_t IPC_freeTaskFromSkeltonResourceDB(uint32_t taskId);
+static RpcResult_t IPC_allocTaskFromSkeltonResourceDB(RpcTaskID_t *taskId,uint32_t *queId);
+static RpcResult_t IPC_freeTaskFromSkeltonResourceDB(RpcTaskID_t taskId);
 
 static IpcSkeltonResourceDBEntry_t *IPC_getIdleSkeltonResource(void);
 static RpcResult_t IPC_allocSkeltonResource(IpcSkeltonResourceDBEntry_t *entry);
+#if	__WORDSIZE == 64
+static RpcBool_t IPC_compareSkeltonResourceByTaskId(RpcList_t *list,uint64_t taskId);
+#else	/* __WORDSIZE */
 static RpcBool_t IPC_compareSkeltonResourceByTaskId(RpcList_t *list,uint32_t taskId);
+#endif	/* __WORDSIZE */
 static RpcBool_t IPC_compareSkeltonResourceByState(RpcList_t *list,uint32_t state);
 
 static RpcResult_t IPC_allocSkeltonManagerResource(void);
@@ -150,8 +158,8 @@ extern RpcResult_t IPC_InitSkelton(RpcBool_t masterProcess) {
 	}
 	/* REGISTER SKELTON DB */
 	pid = RPC_GetPid();
-//	if((ret = IPC_RegisterSkeltonDBEntry(pid,IpcSkeltonManagerTaksId, IpcSkeltonManagerQueId,processType)) != RPC_SUCCESS) {
-	if((ret = IPC_RegisterSkeltonDBEntry(pid,(uint32_t)IpcSkeltonManagerTaksId, IpcSkeltonManagerQueId)) != RPC_SUCCESS) {
+//	if((ret = IPC_RegisterSkeltonDBEntry(pid,IpcSkeltonManagerTaskId, IpcSkeltonManagerQueId,processType)) != RPC_SUCCESS) {
+	if((ret = IPC_RegisterSkeltonDBEntry(pid,(RpcTaskID_t)IpcSkeltonManagerTaskId, IpcSkeltonManagerQueId)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_RegisterSkeltonDBEntry RET:%s;",RPC_LogConvertResultCode(ret));
 		goto goError2;
 	}
@@ -159,11 +167,15 @@ extern RpcResult_t IPC_InitSkelton(RpcBool_t masterProcess) {
 	return ret;
 
 goError2:
-	(void)RPC_CancelTask(IpcSkeltonManagerTaksId);
+	(void)RPC_CancelTask(IpcSkeltonManagerTaskId);
 	(void)IPC_DisableQue(IpcSkeltonManagerQueId);
 	(void)IPC_DestroyQue(IpcSkeltonManagerQueId);
 	IpcSkeltonManagerQueId = 0xFFFFFFFF;
-	IpcSkeltonManagerTaksId = (RpcTaskID_t)0xFFFFFFFF;
+#if	__WORDSIZE == 64
+	IpcSkeltonManagerTaskId = (RpcTaskID_t)0xFFFFFFFFFFFFFFFF;
+#else	/* __WORDSIZE */
+	IpcSkeltonManagerTaskId = (RpcTaskID_t)0xFFFFFFFF;
+#endif	/* __WORDSIZE */
 goError1:
 	(void)IPC_DettachSharedMem();
 #if	0
@@ -228,7 +240,7 @@ static RpcResult_t IPC_initSkeltonResourceDB(void) {
 
 static void *IPC_skeltonManagerMain(void *arg1) {
 	uint32_t queId;uint32_t msgId;RpcMsgParam_t msgParam;RpcResult_t ret;
-	uint32_t newTaskId;uint32_t newQueId;RpcMsgParam_t retMsgParam;
+	RpcTaskID_t newTaskId;uint32_t newQueId;RpcMsgParam_t retMsgParam;
 	uint32_t pid;
 	struct timeval sleepTime;
 
@@ -276,12 +288,12 @@ static void *IPC_skeltonManagerMain(void *arg1) {
 			}
 			break;
 		case IPC_MSG_ID_END_SKELTON:
-			if((ret = IPC_freeTaskFromSkeltonResourceDB(msgParam.u.msgParam.extData)) != RPC_SUCCESS) {
+			if((ret = IPC_freeTaskFromSkeltonResourceDB((RpcTaskID_t)(msgParam.u.skltnLclMsgParam.taskId))) != RPC_SUCCESS) {
 				(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON, RPC_LOG_LEVEL_ERROR, " FAIL TO FREE SKELTON RESOURCE TASK-ID:0x%x; RET:%s;",msgParam.u.msgParam.extData,RPC_LogConvertResultCode(ret));				
 			}
 			break;
 		case IPC_MSG_ID_END_CANCEL:
-			if((ret = IPC_freeTaskFromSkeltonResourceDB(msgParam.u.msgParam.extData)) != RPC_SUCCESS) {
+			if((ret = IPC_freeTaskFromSkeltonResourceDB((RpcTaskID_t)(msgParam.u.skltnLclMsgParam.taskId))) != RPC_SUCCESS) {
 				(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON, RPC_LOG_LEVEL_ERROR, " FAIL TO FREE SKELTON RESOURCE TASK-ID:0x%x; RET:%s;",msgParam.u.msgParam.extData,RPC_LogConvertResultCode(ret));				
 			}
 			break;
@@ -309,7 +321,7 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 	queId = (uint32_t)(*(uint32_t*)arg1);
 	myTaskId = RPC_TaskSelf();
 	RPC_ConvertTimeoutToTimeval(IPC_MSG_QUE_DEFAULT_TIMEOUT,&sleepTime);
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1, "IN IPC_skeltonTaskMain pid:0x%x; queId:0x%x; myTaskId:%d;",pid,queId,myTaskId);
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG1, "IN IPC_skeltonTaskMain pid:0x%x; queId:0x%x; myTaskId:%Ld;",pid,queId,myTaskId);
 	for(;;) {
 		if((ret = IPC_GetMsgFromQue(queId,&msgId,&msgParam,IPC_MSG_QUE_WAIT_FOREVER)) != RPC_SUCCESS) {
 			(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_FATAL, " ERROR in IPC_GetMsgFromQue in SkeltonTaskMain QUE-ID:%d; ret:%s",queId, RPC_LogConvertResultCode(ret));
@@ -324,14 +336,22 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 			if((ret = IPC_SearchFunctionFromFuncDB(msgParam.u.msgParam.funcId,&func,&cancelFunc)) != RPC_SUCCESS) {
 				IPC_SetMsgParam(&retMsgParam,IPC_FUNC_ID_SKELTON_MAIN,pid,queId,msgParam.u.msgParam.seqNum,(uint32_t)ret,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_FUNCTION_REJECT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
 			if(func == NULL) {
 				IPC_SetMsgParam(&retMsgParam,IPC_FUNC_ID_SKELTON_MAIN,pid,queId,msgParam.u.msgParam.seqNum,(uint32_t)ret,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_FUNCTION_REJECT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
@@ -339,7 +359,11 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 			if(!IPC_checkProcessType(msgParam.u.msgParam.srcPid,accessProcessType,pid)) {
 				IPC_SetMsgParam(&retMsgParam,IPC_FUNC_ID_SKELTON_MAIN,pid,queId,msgParam.u.msgParam.seqNum,(uint32_t)IPC_CAN_NOT_EXEC,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_FUNCTION_REJECT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
@@ -349,7 +373,11 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 			if((ret = IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_FUNCTION_ACCEPT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER)) != RPC_SUCCESS) {
 				IPC_SetMsgParam(&retMsgParam,IPC_FUNC_ID_SKELTON_MAIN,pid,queId,msgParam.u.msgParam.seqNum,ret,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_FUNCTION_REJECT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
@@ -366,12 +394,19 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 				}
 				IPC_SetMsgParam(&retMsgParam,msgParam.u.msgParam.funcId,pid,queId,msgParam.u.msgParam.seqNum,(uint32_t)ret,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_FUNCTION_RESPONSE, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
-			retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
-			retMsgParam.u.msgParam.extParam = (void*)NULL;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 			(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 			break;
 		case IPC_MSG_ID_START_CANCEL:
@@ -379,14 +414,22 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 			if((ret = IPC_SearchFunctionFromFuncDB(msgParam.u.msgParam.funcId,&func,&cancelFunc)) != RPC_SUCCESS) {
 				IPC_SetMsgParam(&retMsgParam,IPC_FUNC_ID_SKELTON_MAIN,pid,queId,msgParam.u.msgParam.seqNum,(uint32_t)ret,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_CANCEL_REJECT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_CANCEL, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
 			if(cancelFunc == NULL) {
 				IPC_SetMsgParam(&retMsgParam,IPC_FUNC_ID_SKELTON_MAIN,pid,queId,msgParam.u.msgParam.seqNum,(uint32_t)ret,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_CANCEL_REJECT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_CANCEL, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
@@ -394,8 +437,12 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 			if(!IPC_checkProcessType(msgParam.u.msgParam.srcPid,accessProcessType,pid)) {
 				IPC_SetMsgParam(&retMsgParam,IPC_FUNC_ID_SKELTON_MAIN,pid,queId,msgParam.u.msgParam.seqNum,(uint32_t)IPC_CAN_NOT_EXEC,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_FUNCTION_REJECT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
-				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
+				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_CANCEL, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
 			/* Check Device Type */
@@ -404,16 +451,23 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 			if((ret = IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_CANCEL_ACCEPT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER)) != RPC_SUCCESS) {
 				IPC_SetMsgParam(&retMsgParam,IPC_FUNC_ID_SKELTON_MAIN,pid,queId,msgParam.u.msgParam.seqNum,(uint32_t)ret,(void*)NULL);
 				(void)IPC_PutMsgToExtQue(msgParam.u.msgParam.srcQueId,(uint32_t)IPC_MSG_ID_CANCEL_REJECT, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
-				retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
 				(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_CANCEL, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 				break;
 			}
 			if((funcRet = cancelFunc(msgParam.u.msgParam.srcPid,msgParam.u.msgParam.seqNum)) != RPC_SUCCESS) {
 				(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON, RPC_LOG_LEVEL_WARNING, " FAIL TO EXEC CANCEL ID:0x%x; RET:%s; ERR-CODE:%s;",msgParam.u.msgParam.funcId,RPC_LogConvertResultCode(ret));
 			}
-			retMsgParam.u.msgParam.extData = (uint32_t)myTaskId;
-			retMsgParam.u.msgParam.extParam = (void*)NULL;
-			(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_SKELTON, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
+#if	__WORDSIZE == 64
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint64_t)myTaskId;
+#else	/* __WORDSIZE */
+				retMsgParam.u.skltnLclMsgParam.taskId = (uint32_t)myTaskId;
+#endif	/* __WORDSIZE */
+			(void)IPC_PutMsgToExtQue(IpcSkeltonManagerQueId,(uint32_t)IPC_MSG_ID_END_CANCEL, &retMsgParam, IPC_MSG_QUE_WAIT_FOREVER);
 			break;
 		default:
 			(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_FATAL, " UNKNOWN MSG-ID ID:0x%x;",msgId);
@@ -423,7 +477,7 @@ static void *IPC_skeltonTaskMain(void *arg1) {
 	return (void*)NULL;
 }
 
-static RpcResult_t IPC_allocTaskFromSkeltonResourceDB(uint32_t *taskId,uint32_t *queId) {
+static RpcResult_t IPC_allocTaskFromSkeltonResourceDB(RpcTaskID_t *taskId,uint32_t *queId) {
 	IpcSkeltonResourceDBEntry_t *entry;RpcResult_t ret;
 
 	if((ret = RPC_MutexLock(&(IpcSkeltonRcsDBManage.mutexId))) != RPC_SUCCESS) {
@@ -432,21 +486,25 @@ static RpcResult_t IPC_allocTaskFromSkeltonResourceDB(uint32_t *taskId,uint32_t
 	if((entry = IPC_getIdleSkeltonResource()) == (IpcSkeltonResourceDBEntry_t*)NULL) {
 		return RPC_NO_MORE_RESOURCE;
 	}
-	*taskId = (uint32_t)entry->taskId;
+	*taskId = (RpcTaskID_t)entry->taskId;
 	*queId = entry->queId;
 	entry->state = RPC_RESOURCE_BUSY_STATE;
 	(void)RPC_MutexUnlock(&(IpcSkeltonRcsDBManage.mutexId));
 	return RPC_SUCCESS;
 }
 
-static RpcResult_t IPC_freeTaskFromSkeltonResourceDB(uint32_t taskId) {
+static RpcResult_t IPC_freeTaskFromSkeltonResourceDB(RpcTaskID_t taskId) {
 	IpcSkeltonResourceDBEntry_t *entry;RpcResult_t ret;
 
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON, RPC_LOG_LEVEL_DEBUG2,"IN IPC_freeTaskFromSkeltonResourceDB PID:0x%x; taskId:0x%x",RPC_GetPid(),taskId);
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON, RPC_LOG_LEVEL_DEBUG2,"IN IPC_freeTaskFromSkeltonResourceDB PID:0x%x; taskId:0x%Lx",RPC_GetPid(),taskId);
 	if((ret = RPC_MutexLock(&(IpcSkeltonRcsDBManage.mutexId))) != RPC_SUCCESS) {
 		return ret;
 	}
-	if((entry = (IpcSkeltonResourceDBEntry_t*)RPC_SearchListEntryById(IpcSkeltonRcsDBManage.skeltonResourceList,taskId,IPC_compareSkeltonResourceByTaskId)) == (void*)NULL) {
+#if	__WORDSIZE == 64
+	if((entry = (IpcSkeltonResourceDBEntry_t*)RPC_SearchListEntryByDwordId(IpcSkeltonRcsDBManage.skeltonResourceList,(uint64_t)taskId,IPC_compareSkeltonResourceByTaskId)) == (void*)NULL) {
+#else	/* __WORDSIZE */
+	if((entry = (IpcSkeltonResourceDBEntry_t*)RPC_SearchListEntryById(IpcSkeltonRcsDBManage.skeltonResourceList,(uint32_t)taskId,IPC_compareSkeltonResourceByTaskId)) == (void*)NULL) {
+#endif	/* __WORDSIZE */
 		return RPC_PARAM_ERROR;
 	}
 	entry->state = RPC_RESOURCE_IDLE_STATE;
@@ -483,6 +541,16 @@ static IpcSkeltonResourceDBEntry_t *IPC_getIdleSkeltonResource(void) {
 	return new;
 }
 
+#if	__WORDSIZE == 64
+static RpcBool_t IPC_compareSkeltonResourceByTaskId(RpcList_t *list,uint64_t taskId) {
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG3,"IN IPC_compareSkeltonResourceByTaskId TASKID:0x%Lx; ORG:0x%Lx;",
+//		taskId, ((IpcSkeltonResourceDBEntry_t*)list->entry)->taskId);
+	if((uint64_t)(((IpcSkeltonResourceDBEntry_t*)list->entry)->taskId) == taskId)
+		return RPC_TRUE;
+	else
+		return RPC_FALSE;
+}
+#else	/* __WORDSIZE */
 static RpcBool_t IPC_compareSkeltonResourceByTaskId(RpcList_t *list,uint32_t taskId) {
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_DEBUG3,"IN IPC_compareSkeltonResourceByTaskId TASKID:0x%x; ORG:0x%x;",
 //		taskId, ((IpcSkeltonResourceDBEntry_t*)list->entry)->taskId);
@@ -491,6 +559,7 @@ static RpcBool_t IPC_compareSkeltonResourceByTaskId(RpcList_t *list,uint32_t tas
 	else
 		return RPC_FALSE;
 }
+#endif	/* __WORDSIZE */
 
 static RpcBool_t IPC_compareSkeltonResourceByState(RpcList_t *list,uint32_t state) {
 	if((uint32_t)(((IpcSkeltonResourceDBEntry_t*)list->entry)->state) == state)
@@ -600,7 +669,7 @@ static RpcResult_t IPC_allocSkeltonManagerResource(void) {
 		return ret;	
 	}
 	IpcSkeltonManagerQueId = queId;
-	if((ret = RPC_CreateTask(&(IpcSkeltonManagerTaksId), &(IpcSkeltonManagerTaskAttr), IPC_skeltonManagerMain, (void*)&(IpcSkeltonManagerQueId))) != RPC_SUCCESS) {
+	if((ret = RPC_CreateTask(&(IpcSkeltonManagerTaskId), &(IpcSkeltonManagerTaskAttr), IPC_skeltonManagerMain, (void*)&(IpcSkeltonManagerQueId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_SKELTON,RPC_LOG_LEVEL_FATAL, " CAN NOT CREATE TASK ret:%s",RPC_LogConvertResultCode(ret));
 		(void)IPC_DisableQue(queId);
 		(void)IPC_DestroyQue(queId);
