@@ -152,8 +152,13 @@ static IpcStubFuncInfo_t *IPC_searchStubDBEntryBySeqNum(uint32_t seqNum);
 static IpcStubFuncInfo_t *IPC_searchStubDBEntryByOrgTaskId(RpcTaskID_t orgTaskId);
 static IpcStubFuncInfo_t *IPC_searchStubDBEntryByCBTaskId(RpcTaskID_t cbTaskId);
 static RpcBool_t IPC_compareStubFuncDBBySeqNum(RpcList_t *list,uint32_t seqNum);
+#if	__WORDSIZE == 64
+static RpcBool_t IPC_compareStubFuncDBByOrgTaskId(RpcList_t *list,uint64_t orgTaskId);
+static RpcBool_t IPC_compareStubFuncDBByCBTaskId(RpcList_t *list,uint64_t cbTaskId);
+#else	/* __WORDSIZE */
 static RpcBool_t IPC_compareStubFuncDBByOrgTaskId(RpcList_t *list,uint32_t orgTaskId);
 static RpcBool_t IPC_compareStubFuncDBByCBTaskId(RpcList_t *list,uint32_t cbTaskId);
+#endif	/* __WORDSIZE */
 
 static RpcResult_t IPC_allocCBTaskFromStubResourceDB(RpcTaskID_t *taskId,RpcTaskControl_t **tskCntl);
 static RpcResult_t IPC_freeCBTaskFromStubResourceDB(RpcTaskID_t taskId);
@@ -165,7 +170,11 @@ static IpcStubQueResourceDBEntry_t *IPC_getIdleStubQueResource(void);
 
 static RpcBool_t IPC_compareQueResourceByQueId(RpcList_t *list,uint32_t queId);
 static RpcBool_t IPC_compareQueResourceByState(RpcList_t *list,uint32_t state);
+#if	__WORDSIZE == 64
+static RpcBool_t IPC_compareCBTaskResourceByTaskId(RpcList_t *list,uint64_t taskId);
+#else	/* __WORDSIZE */
 static RpcBool_t IPC_compareCBTaskResourceByTaskId(RpcList_t *list,uint32_t taskId);
+#endif	/* __WORDSIZE */
 static RpcBool_t IPC_compareCBTaskResourceByState(RpcList_t *list,uint32_t state);
 
 static RpcResult_t IPC_allocStubCBTaskResource(IpcStubCBTaskResourceDBEntry_t *entry);
@@ -182,12 +191,16 @@ static void IPC_mltcstCallback(uint32_t seqNum,void *outData,uint32_t outSize,ui
 static IpcMltcstRetCntl_t *IPC_addStubMltcstCntlEntry(IpcFunctionType_t funcType, uint32_t mltcstFuncId,RpcTaskID_t callTaskId, IpcStubMltcstResourceDBEntry_t *mltcstMutex,IPC_MultticastCallbackFunc_t callbackFunc);
 static void IPC_deleteStubMltcstCntlEntry(IpcMltcstRetCntl_t *entry);
 static IpcFuncRetVal_t *IPC_searchStubMltcstCntlEntryBySeqNum(uint32_t seqNum,IpcMltcstRetCntl_t **mltcstRetCntl);
-static RpcResult_t IPC_allocMltcstFromStubResourceDB(uint32_t taskId,IpcStubMltcstResourceDBEntry_t **entry);
-static RpcResult_t IPC_freeMltcstFromStubResourceDB(uint32_t taskId);
+static RpcResult_t IPC_allocMltcstFromStubResourceDB(RpcTaskID_t taskId,IpcStubMltcstResourceDBEntry_t **entry);
+static RpcResult_t IPC_freeMltcstFromStubResourceDB(RpcTaskID_t taskId);
 static IpcStubMltcstResourceDBEntry_t *IPC_getIdleStubMltcstResource(void);
 static RpcResult_t IPC_allocStubMltcstResource(IpcStubMltcstResourceDBEntry_t *mEntry);
 static RpcBool_t IPC_compareMltcstResourceByState(RpcList_t *list,uint32_t state);
+#if	__WORDSIZE == 64
+static RpcBool_t IPC_compareMltcstResourceByTaskId(RpcList_t *list,uint64_t taskId);
+#else	/* __WORDSIZE */
 static RpcBool_t IPC_compareMltcstResourceByTaskId(RpcList_t *list,uint32_t taskId);
+#endif	/* __WORDSIZE */
 //static RpcBool_t IPC_compareStubMltcstCntlByMltcstFuncId(RpcList_t *list,uint32_t mltcstFuncId);
 static RpcBool_t IPC_compareStubMltcstRetValBySeqNum(RpcList_t *list,uint32_t seqNum);
 #endif	/* USE_MULTICAST_RPC */
@@ -300,7 +313,7 @@ extern RpcResult_t IPC_CallStubSync(uint32_t funcID, void *inData, uint32_t inSi
 		goto errorOut3;
 	}
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB, RPC_LOG_LEVEL_DEBUG2, "  FIND PROCESS ID FROM FUNCID FUNCID:0x%x; PID:0x%x;",funcID,dstProcessId);
-	if((ret = IPC_SearchSkeltonDB(dstProcessId,(uint32_t*)&dstTaskId,&dstQueId)) != RPC_SUCCESS) {
+	if((ret = IPC_SearchSkeltonDB(dstProcessId,(RpcTaskID_t*)&dstTaskId,&dstQueId)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB, RPC_LOG_LEVEL_ERROR, " AN NOT FIND SKELTON RET:%s;",RPC_LogConvertResultCode(ret));
 		*errCode = RPC_ERR_OTHER;
 		goto errorOut3;
@@ -321,7 +334,7 @@ extern RpcResult_t IPC_CallStubSync(uint32_t funcID, void *inData, uint32_t inSi
 		ret = RPC_TIMEOUT_ERROR;
 		goto errorOut4;						
 	}
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB, RPC_LOG_LEVEL_DEBUG2, "  REGISTER STUB INFO FUNCID:0x%x; SEQ-NUM:0x%x; dsRpcTaskID_t:0x%x; orgTaskID:0x%x; SRC-QUEID:0x%x;",
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB, RPC_LOG_LEVEL_DEBUG2, "  REGISTER STUB INFO FUNCID:0x%x; SEQ-NUM:0x%x; dstRpcTaskID_t:0x%Lx; orgTaskID:0x%Lx; SRC-QUEID:0x%x;",
 //		funcID,seqNum,dstTaskId, orgTaskId,srcQueId);
 	if(!RPC_GetRestTimeout(&absTime,&timeOut)) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB, RPC_LOG_LEVEL_ERROR, " OCCUR TIMEOUT");
@@ -464,7 +477,7 @@ extern RpcResult_t IPC_CallStubAsync(uint32_t funcID, void *inData, uint32_t inS
 		*errCode = RPC_ERR_OTHER;
 		goto errorOut3;
 	}
-	if((ret = IPC_SearchSkeltonDB(dstProcessId,(uint32_t*)&dstTaskId,&dstQueId)) != RPC_SUCCESS) {
+	if((ret = IPC_SearchSkeltonDB(dstProcessId,(RpcTaskID_t*)&dstTaskId,&dstQueId)) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB, RPC_LOG_LEVEL_ERROR, " CAN NOT FIND SKELTON RET:%s;",RPC_LogConvertResultCode(ret));
 		*errCode = RPC_ERR_OTHER;
 		goto errorOut3;
@@ -800,7 +813,7 @@ static void *IPC_CBTaskMain(void *arg1) {
 	for(;;) {
 		if((ret = RPC_TaskControlWait(tskCntl)) != RPC_SUCCESS)
 			continue;
-//		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG2,"  WAKE UP TAKS IN STUB-CB-TASK PID:0x%x;",RPC_GetPid());
+//		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG2,"  WAKE UP TASK IN STUB-CB-TASK PID:0x%Lx; TaskId:0x%Lx; TaskCntl:0x%Lx;",RPC_GetPid(),myTaskId,tskCntl);
 		if((stubInfo = IPC_searchStubDBEntryByCBTaskId(myTaskId)) == (IpcStubFuncInfo_t*)NULL) {
 			(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_FATAL, " ERROR in IPC_searchStubDBEntryByCBTaskId");
 			continue;
@@ -867,7 +880,7 @@ goOut:
 
 static RpcResult_t IPC_execCancelFunc(uint32_t funcId,uint32_t seqNum,uint32_t *errCode) {
 	RpcResult_t ret = RPC_SUCCESS;RpcMsgParam_t msgParam;uint32_t srcProcessId;uint32_t srcQueId;
-	RpcMsgId_t msgId;uint32_t dstProcessId;uint32_t dstTaskId;uint32_t dstQueId;
+	RpcMsgId_t msgId;uint32_t dstProcessId;RpcTaskID_t dstTaskId;uint32_t dstQueId;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_DEBUG1,"IN IPC_execCancelFunc PID:0x%x; funcId:0x%x; seqNum:0x%x;",RPC_GetPid(),funcId,seqNum);
 	if((ret = IPC_SerachProcessIdFromFuncDB(funcId,&dstProcessId)) != RPC_SUCCESS) {
@@ -996,7 +1009,11 @@ static IpcStubFuncInfo_t *IPC_searchStubDBEntryByOrgTaskId(RpcTaskID_t orgTaskId
 	if(RPC_MutexLock(&(IpcStubDataManage.mutexId)) != RPC_SUCCESS) {
 		return (IpcStubFuncInfo_t*)NULL;
 	}
+#if	__WORDSIZE == 64
+	if((funcInfo = RPC_SearchListEntryByDwordId(IpcStubDataManage.stubFuncDBList,(uint64_t)orgTaskId,IPC_compareStubFuncDBByOrgTaskId)) != (IpcStubFuncInfo_t*)NULL) {
+#else	/* __WORDSIZE */
 	if((funcInfo = RPC_SearchListEntryById(IpcStubDataManage.stubFuncDBList,(uint32_t)orgTaskId,IPC_compareStubFuncDBByOrgTaskId)) != (IpcStubFuncInfo_t*)NULL) {
+#endif	/* __WORDSIZE */
 		RPC_MutexUnlock(&(IpcStubDataManage.mutexId));
 		return funcInfo;
 	}
@@ -1012,7 +1029,11 @@ static IpcStubFuncInfo_t *IPC_searchStubDBEntryByCBTaskId(RpcTaskID_t cbTaskId)
 	if(RPC_MutexLock(&(IpcStubDataManage.mutexId)) != RPC_SUCCESS) {
 		return (IpcStubFuncInfo_t*)NULL;
 	}
+#if	__WORDSIZE == 64
+	if((funcInfo = RPC_SearchListEntryByDwordId(IpcStubDataManage.stubFuncDBList,(uint64_t)cbTaskId,IPC_compareStubFuncDBByCBTaskId)) != (IpcStubFuncInfo_t*)NULL) {
+#else	/* __WORDSIZE */
 	if((funcInfo = RPC_SearchListEntryById(IpcStubDataManage.stubFuncDBList,(uint32_t)cbTaskId,IPC_compareStubFuncDBByCBTaskId)) != (IpcStubFuncInfo_t*)NULL) {
+#endif	/* __WORDSIZE */
 		RPC_MutexUnlock(&(IpcStubDataManage.mutexId));
 		return funcInfo;
 	}
@@ -1029,6 +1050,21 @@ static RpcBool_t IPC_compareStubFuncDBBySeqNum(RpcList_t *list,uint32_t seqNum)
 		return RPC_FALSE;
 }
 
+#if	__WORDSIZE == 64
+static RpcBool_t IPC_compareStubFuncDBByOrgTaskId(RpcList_t *list,uint64_t orgTaskId) {
+	if(((IpcStubFuncInfo_t*)(list->entry))->orgTaskId == (RpcTaskID_t)orgTaskId)
+		return RPC_TRUE;
+	else
+		return RPC_FALSE;
+}
+
+static RpcBool_t IPC_compareStubFuncDBByCBTaskId(RpcList_t *list,uint64_t cbTaskId) {
+	if(((IpcStubFuncInfo_t*)(list->entry))->cbInfo.cbTaskId == (RpcTaskID_t)cbTaskId)
+		return RPC_TRUE;
+	else
+		return RPC_FALSE;
+}
+#else	/* __WORDSIZE */
 static RpcBool_t IPC_compareStubFuncDBByOrgTaskId(RpcList_t *list,uint32_t orgTaskId) {
 	if(((IpcStubFuncInfo_t*)(list->entry))->orgTaskId == (RpcTaskID_t)orgTaskId)
 		return RPC_TRUE;
@@ -1042,6 +1078,7 @@ static RpcBool_t IPC_compareStubFuncDBByCBTaskId(RpcList_t *list,uint32_t cbTask
 	else
 		return RPC_FALSE;
 }
+#endif	/* __WORDSIZE */
 
 static RpcResult_t IPC_allocCBTaskFromStubResourceDB(RpcTaskID_t *taskId,RpcTaskControl_t **tskCntl) {
 	IpcStubCBTaskResourceDBEntry_t *entry;RpcResult_t ret;
@@ -1066,9 +1103,13 @@ static RpcResult_t IPC_freeCBTaskFromStubResourceDB(RpcTaskID_t taskId) {
 	if((ret = RPC_MutexLock(&(IpcStubRcsDBManage.mutexId))) != RPC_SUCCESS) {
 		return ret;
 	}
+#if	__WORDSIZE == 64
+	if((entry = (IpcStubCBTaskResourceDBEntry_t*)RPC_SearchListEntryByDwordId(IpcStubRcsDBManage.stubCBTaskResourceList,(uint64_t)taskId,IPC_compareCBTaskResourceByTaskId)) == (IpcStubCBTaskResourceDBEntry_t*)NULL) {
+#else	/* __WORDSIZE */
 	if((entry = (IpcStubCBTaskResourceDBEntry_t*)RPC_SearchListEntryById(IpcStubRcsDBManage.stubCBTaskResourceList,(uint32_t)taskId,IPC_compareCBTaskResourceByTaskId)) == (IpcStubCBTaskResourceDBEntry_t*)NULL) {
+#endif	/* __WORDSIZE */
 		(void)RPC_MutexUnlock(&(IpcStubRcsDBManage.mutexId));
-		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_ERROR,"CAN NOT FIND ENTRY BY TAKSID:0x%x;",taskId);
+		(void)RPC_LogPrint(RPC_LOG_MODULE_STUB,RPC_LOG_LEVEL_ERROR,"CAN NOT FIND ENTRY BY TASKID:0x%Lx;",taskId);
 		return RPC_PARAM_ERROR;
 	}
 	entry->taskState = RPC_RESOURCE_IDLE_STATE;
@@ -1172,12 +1213,21 @@ static IpcStubQueResourceDBEntry_t *IPC_getIdleStubQueResource(void) {
 	return new;
 }
 
+#if	__WORDSIZE == 64
+static RpcBool_t IPC_compareCBTaskResourceByTaskId(RpcList_t *list,uint64_t taskId) {
+	if((uint64_t)(((IpcStubCBTaskResourceDBEntry_t*)list->entry)->taskId) == taskId)
+		return RPC_TRUE;
+	else
+		return RPC_FALSE;
+}
+#else	/* __WORDSIZE */
 static RpcBool_t IPC_compareCBTaskResourceByTaskId(RpcList_t *list,uint32_t taskId) {
 	if((uint32_t)(((IpcStubCBTaskResourceDBEntry_t*)list->entry)->taskId) == taskId)
 		return RPC_TRUE;
 	else
 		return RPC_FALSE;
 }
+#endif	/* __WORDSIZE */
 
 static RpcBool_t IPC_compareCBTaskResourceByState(RpcList_t *list,uint32_t state) {
 	if((uint32_t)(((IpcStubCBTaskResourceDBEntry_t*)list->entry)->taskState) == state)
@@ -1768,10 +1818,10 @@ static IpcFuncRetVal_t *IPC_searchStubMltcstCntlEntryBySeqNum(uint32_t seqNum,Ip
 	return retValData;
 }
 
-static RpcResult_t IPC_allocMltcstFromStubResourceDB(uint32_t taskId,IpcStubMltcstResourceDBEntry_t **entry) {
+static RpcResult_t IPC_allocMltcstFromStubResourceDB(RpcTaskID_t taskId,IpcStubMltcstResourceDBEntry_t **entry) {
 	IpcStubMltcstResourceDBEntry_t *p;RpcResult_t ret;
 
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MLTCST,RPC_LOG_LEVEL_DEBUG2,"IN IPC_allocMltcstFromStubResourceDB taskId:0x%x;",taskId);
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MLTCST,RPC_LOG_LEVEL_DEBUG2,"IN IPC_allocMltcstFromStubResourceDB taskId:0x%Lx;",taskId);
 	*entry = (IpcStubMltcstResourceDBEntry_t*)NULL;
 	if((ret = RPC_MutexLock(&(IpcStubRcsDBManage.mutexId))) != RPC_SUCCESS) {
 		return ret;
@@ -1788,19 +1838,23 @@ static RpcResult_t IPC_allocMltcstFromStubResourceDB(uint32_t taskId,IpcStubMltc
 	return RPC_SUCCESS;
 }
 
-static RpcResult_t IPC_freeMltcstFromStubResourceDB(uint32_t taskId) {
+static RpcResult_t IPC_freeMltcstFromStubResourceDB(RpcTaskID_t taskId) {
 	IpcStubMltcstResourceDBEntry_t *entry;RpcResult_t ret;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MLTCST,RPC_LOG_LEVEL_DEBUG2,"IN IPC_freeMltcstFromStubResourceDB taskId:0x%x;",taskId);
 	if((ret = RPC_MutexLock(&(IpcStubRcsDBManage.mutexId))) != RPC_SUCCESS) {
 		return ret;
 	}
+#if	__WORDSIZE == 64
+	if((entry = (IpcStubMltcstResourceDBEntry_t*)RPC_SearchListEntryByDwordId(IpcStubRcsDBManage.stubMltcstResourceList,taskId,IPC_compareMltcstResourceByTaskId)) == (IpcStubMltcstResourceDBEntry_t*)NULL) {
+#else	/* __WORDSIZE */
 	if((entry = (IpcStubMltcstResourceDBEntry_t*)RPC_SearchListEntryById(IpcStubRcsDBManage.stubMltcstResourceList,taskId,IPC_compareMltcstResourceByTaskId)) == (IpcStubMltcstResourceDBEntry_t*)NULL) {
+#endif	/* __WORDSIZE */
 		(void)RPC_MutexUnlock(&(IpcStubRcsDBManage.mutexId));
 		return RPC_PARAM_ERROR;
 	}
 	entry->mltcstState = RPC_RESOURCE_IDLE_STATE;
-	entry->taskId = 0;
+	entry->taskId = 0L;
 	(void)RPC_MutexUnlock(&(IpcStubRcsDBManage.mutexId));
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MLTCST,RPC_LOG_LEVEL_DEBUG2,"OUT IPC_freeMltcstFromStubResourceDB ");
 	return RPC_SUCCESS;
@@ -1838,7 +1892,7 @@ static RpcResult_t IPC_allocStubMltcstResource(IpcStubMltcstResourceDBEntry_t *m
 		return ret;
 	}
 	mEntry->mltcstState = RPC_RESOURCE_IDLE_STATE;
-	mEntry->taskId = 0;
+	mEntry->taskId = 0L;
 	return RPC_SUCCESS;
 }
 
@@ -1854,12 +1908,21 @@ static RpcBool_t IPC_compareMltcstResourceByState(RpcList_t *list,uint32_t state
 	}
 }
 
+#if	__WORDSIZE == 64
+static RpcBool_t IPC_compareMltcstResourceByTaskId(RpcList_t *list,uint64_t taskId) {
+	if((uint64_t)(((IpcStubMltcstResourceDBEntry_t*)list->entry)->taskId) == taskId)
+		return RPC_TRUE;
+	else
+		return RPC_FALSE;
+}
+#else	/* __WORDSIZE */
 static RpcBool_t IPC_compareMltcstResourceByTaskId(RpcList_t *list,uint32_t taskId) {
 	if((uint32_t)(((IpcStubMltcstResourceDBEntry_t*)list->entry)->taskId) == taskId)
 		return RPC_TRUE;
 	else
 		return RPC_FALSE;
 }
+#endif	/* __WORDSIZE */
 
 /*
 static RpcBool_t IPC_compareStubMltcstCntlByMltcstFuncId(RpcList_t *list,uint32_t mltcstFuncId) {
