@@ -33,7 +33,11 @@
 
 #include	"ipcType.h"
 
+#if	__WORDSIZE == 64
+#define	MSG_PARAM_DATA_SIZE		(7*4)
+#else	/* __WORDSIZE */
 #define	MSG_PARAM_DATA_SIZE		(6*4)
+#endif	/* __WORDSIZE */
 
 typedef struct {
 	uint32_t funcId;
@@ -44,9 +48,20 @@ typedef struct {
 	void *extParam;
 } ipcMsgParam_t;
 
+typedef struct {
+#if	__WORDSIZE == 64
+	uint64_t taskId;
+	uint32_t padding[5];
+#else	/* __WORDSIZE */
+	uint32_t taskId;
+	uint32_t padding[5];
+#endif	/* __WORDSIZE */
+} ipcSkltnLclMsgParam_t;
+
 typedef struct {
 	union {
 		ipcMsgParam_t msgParam;
+		ipcSkltnLclMsgParam_t skltnLclMsgParam;
 		uint8_t paramData[MSG_PARAM_DATA_SIZE];
 	}u;
 } RpcMsgParam_t;
